# <font style="background-color:#52C41A;"> </font> 功能说明
支持**查询**、**订阅** 2种获取轨迹的方式

:::tips
**查询**

通过运单号和物流公司编码查询此单当前的轨迹,

<font style="color:#DF2A3F;">注意：因国际节点问题可能需要多次请求</font>

:::

:::tips
**订阅**

通过运单号和物流公司编码注册订阅，并配置自己的回调地址，每当轨迹更新，快递鸟推送新轨迹至此地址，直至签收

:::

_<font style="color:#585A5A;">如您第一次使用快递鸟，请参考</font>_[_<font style="color:#117CEE;">API参数示意图</font>_](https://www.yuque.com/kdnjishuzhichi/dfcrg1/hl2gthcuqft7rm34)



## <font style="background-color:#52C41A;"> </font>_<font style="color:#117CEE;"> </font>_接口信息
| **RequestType** | **<font style="color:#0070C0;">7101  </font>**<font style="color:#585A5A;">查询</font>**<font style="color:#0070C0;">  /  7108  </font>**<font style="color:#585A5A;">订阅</font> |
| --- | --- |
| **<font style="color:black;">计费规则</font>** | <font style="color:#585A5A;">40个自然日内同一（物流编码+单号）不限查询次数，计费1单；</font><br/><font style="color:#585A5A;">查询无轨迹不计费</font> |
| **轨迹排序** | 默认按照发生时间的**升序**排列 |
| **<font style="color:black;">接口地址</font>** |  https://globapi.kdniao.com/api/track/packet |




## <font style="background-color:#52C41A;"> </font>_<font style="color:#117CEE;"> </font>_支持情况
[跨境小包.xls](https://www.yuque.com/attachments/yuque/0/2025/xls/32723986/1755228588801-0917717d-df40-48c8-a087-b8f901e35cf3.xls)

---

# <font style="color:#5C0036;background-color:#D22D8D;"> </font><font style="color:#5C0036;"> </font>查询
##  <font style="background-color:#52C41A;"> </font> 请求示例
```json
{
"ShipperCode": "COE",
"LogisticCode": "EL796371469MO"
}
```

```basic
RequestData: {
"ShipperCode": "COE",
"LogisticCode": "EL796371469MO"
},
DataType: "2",
EBusinessID: "1000000",
DataSign: "M2JmNjI5mYWZkZTFmOTUxNWYwMZTQzOTQyNjczZThTM=",
RequestType: "7101"
```

###  <font style="background-color:#1890FF;"> </font> 业务参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| ShipperCode | <font style="color:#585A5A;">String(10)</font> | - [x] <font style="color:black;"></font> | 物流公司编码 <font style="color:#8A8F8D;">   见支持表--物流商简码</font> |
| LogisticCode | <font style="color:#585A5A;">String(30)</font> | - [x] <font style="color:black;"></font> | 快递单号 |
| OrderCode | <font style="color:#585A5A;">String(30)</font> | - [ ]  | 订单编号 |
| CallBack | <font style="color:#585A5A;">String(50)</font> | - [ ]  | 用户自定义回传字段 |
| <font style="color:black;">CustomerName</font> | <font style="color:#585A5A;">String(50)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#333333;">客户名称</font> |
| Language | <font style="color:#585A5A;">String(30)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#8A8F8D;">不传，待更新...</font> |


 

## <font style="background-color:#52C41A;"> </font> 返回参数
当接口返回无轨迹时请参考下表中的**物流状态**和返回**reason**进行处理

| **<font style="color:#FFFFFF;">名称</font>** | | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- | --- |
| EBusinessID | | <font style="color:#585A5A;">String(10)</font> | - [x]  | 用户ID |
| ShipperCode | | <font style="color:#585A5A;">String(10)</font> | - [x]  | 快递公司编码 |
| LogisticCode | | <font style="color:#585A5A;">String(30)</font> | - [x]  | 快递单号 |
| Success | | <font style="color:#585A5A;">Bool</font><font style="color:#585A5A;">(10)</font> | - [x]  | 成功与否<font style="color:#585A5A;">(true/false)</font> |
| Reason | | <font style="color:#585A5A;">String(50)</font> | - [ ]  | 失败原因 |
| State | | <font style="color:#585A5A;">String(5)</font> | - [x] <font style="color:black;"></font> | [物流状态编码 跨境](https://www.yuque.com/kdnjishuzhichi/weubcu/mrk6deexp7v4ruxu)  |
| StateEx<br/><br/><br/> | | | |
| Location | | <font style="color:#585A5A;">String(20)</font> | - [x] <font style="color:black;"></font> | <font style="color:black;">当前所在城市</font> |
| Traces | <font style="color:#5C8D07;">Timezone</font> | <font style="color:#585A5A;">String(32)</font> | - [ ]  | 轨迹时区-05:00 |
| | <font style="color:#5c8d07;">AcceptTime</font> | <font style="color:#585A5A;">String(20)</font> | - [x]  | 轨迹发生时间，示例：<br/>`2024-06-28T11:23:51` |
| | <font style="color:#5C8D07;">AcceptStation</font> | <font style="color:#585A5A;">String(500)</font> | - [x]  | 轨迹描述 |
| | <font style="color:#5C8D07;">Location</font> | <font style="color:#585A5A;">String(20)</font> | - [ ]  | <font style="color:#333333;">国家/地区、州、城市</font><font style="color:#333333;">（STOCKTON,CA,US）</font> |
| | <font style="color:#5C8D07;">Action</font> | <font style="color:#585A5A;">String(50)</font> | - [x]  | 同 **StateEx** |


```json
{
    "EBusinessID": "1000000",
    "ShipperCode": "COLISSIMO",
    "LogisticCode": "6A37856101056",
    "State": "3",
    "StateEx": "301",
    "Location": "",
    "Traces": [
        {
            "Action": "1",
            "AcceptStation": "Your parcel will soon be handed over to us! It is being prepared by the sender.",
            "AcceptTime": "2024-05-27 20:09:27",
            "Location": "XX,XX,XX",
            "Timezone": "+02:00"
        },
        {
            "Action": "2",
            "AcceptStation": "Your parcel is transiting through our logistics platforms.",
            "AcceptTime": "2024-05-29 14:30:57",
            "Timezone": "+02:00"
        },
        {
            "Action": "2",
            "AcceptStation": "Your parcel is transiting through our logistics platforms.",
            "AcceptTime": "2024-05-30 14:37:01",
            "Timezone": "+02:00"
        },
        {
            "Action": "211",
            "AcceptStation": "Your parcel is at the delivery site that serves your address. We are preparing it for delivery.",
            "AcceptTime": "2024-06-01 08:04:56",
            "Timezone": "+02:00"
        },
        {
            "Action": "301",
            "AcceptStation": "Your parcel has been delivered in your letter box.",
            "AcceptTime": "2024-06-01 11:03:15",
            "Timezone": "+02:00"
        }
    ],
    "Success": true
}
```







---

# <font style="color:#5C0036;background-color:#D22D8D;"> </font><font style="color:#5C0036;"> </font>订阅
## <font style="color:#5C0036;"> </font><font style="background-color:#52C41A;"> </font><font style="color:#5C0036;">  </font>请求示例
```json
{
"ShipperCode": "COE",
"LogisticCode": "EL796371469MO"
}
```

```basic
RequestData: {
"ShipperCode": "COE",
"LogisticCode": "EL796371469MO"
},
DataType: "2",
EBusinessID: "1000000",
DataSign: "M2JmNjI5mYWZkZTFmOTUxNWYwMZTQzOTQyNjczZThTM=",
RequestType: "7108"
```

###  <font style="background-color:#1890FF;"> </font> 业务参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| ShipperCode | <font style="color:#585A5A;">String(10)</font> | - [x] <font style="color:black;"></font> | 物流公司编码 <font style="color:#8A8F8D;">   见支持表--物流商简码</font> |
| LogisticCode | <font style="color:#585A5A;">String(30)</font> | - [x] <font style="color:black;"></font> | 快递单号 |
| OrderCode | <font style="color:#585A5A;">String(30)</font> | - [ ]  | 订单编号 |
| <font style="color:black;">CustomerName</font> | <font style="color:#585A5A;">String(50)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#333333;">客户名称</font> |
| Language | <font style="color:#585A5A;">String(30)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#8A8F8D;">不传，待更新...</font> |
| CallbackUrl | <font style="color:#585A5A;">String(255)</font> | - [ ] <font style="color:black;"></font> | 轨迹回调地址 |


 

## <font style="background-color:#52C41A;"> </font> 返回参数
| **<font style="color:#FFFFFF;">名称</font>** | **<font style="color:#FFFFFF;">类型(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- |
| EBusinessID | <font style="color:#8A8F8D;">String(10)</font> | - [x]  | 用户ID |
| UpdateTime | <font style="color:#8A8F8D;">String(32)</font> | - [x]  | 更新时间 |
| Success | <font style="color:#8A8F8D;">Bool(10)</font> | - [x]  | 成功与否<font style="color:#585A5A;">(true/false)</font> |
| ShipperCode | <font style="color:#8A8F8D;">String(10)</font> | - [ ]  | 快递公司编码 |
| LogisticCode | <font style="color:#8A8F8D;">String(30)</font> | - [ ]  | 快递单号 |
| Reason | <font style="color:#8A8F8D;">String(50)</font> | - [ ]  | 失败原因 |


```json
{
  "ShipperCode": "FEDEX",
  "UpdateTime": "2024-06-28 14:37:02",
  "EBusinessID": "1279441",
  "Success": true
}
```

---

# <font style="color:#5C0036;background-color:#D22D8D;"> </font><font style="color:#5C0036;"> </font>推送
###  <font style="background-color:#52C41A;"> </font> 推送示例
```json
{
	"Count": "1",
	"Data": [{
		"EBusinessID": "1000001",
		"Location": "",
		"LogisticCode": "6A37856075760",
		"ShipperCode": "COLISSIMO",
		"State": "3",
		"StateEx": "301",
		"Success": true,
		"Traces": [{
			"AcceptStation": "Your parcel has been delivered in your letter box.",
			"AcceptTime": "2024-05-30 10:06:18",
			"Action": "301",
			"Location": "",
			"Remark": "",
			"Timezone": "+02:00"
		}, {
			"AcceptStation": "Your parcel is at the delivery site that serves your address. We are preparing it for delivery.",
			"AcceptTime": "2024-05-30 07:36:42",
			"Action": "211",
			"Location": "",
			"Remark": "",
			"Timezone": "+02:00"
		}, {
			"AcceptStation": "Your parcel is transiting through our logistics platforms.",
			"AcceptTime": "2024-05-29 13:00:05",
			"Action": "2",
			"Location": "",
			"Remark": "",
			"Timezone": "+02:00"
		}, {
			"AcceptStation": "Your parcel will soon be handed over to us! It is being prepared by the sender.",
			"AcceptTime": "2024-05-27 18:11:11",
			"Action": "1",
			"Location": "",
			"Remark": "",
			"Timezone": "+02:00"
		}]
	}],
	"EBusinessID": "100001",
	"PushTime": "2024-06-27 21:07:00"
}
```



### <font style="background-color:#1890FF;"> </font> 推送参数
| **<font style="color:#FFFFFF;">名称</font>** | | | **<font style="color:#FFFFFF;">类型</font>****<font style="color:#FFFFFF;">(长度)</font>** | **<font style="color:#FFFFFF;">是否必须</font>** | **<font style="color:#FFFFFF;">描述</font>** |
| --- | --- | --- | --- | --- | --- |
| EBusinessID | | | <font style="color:#585A5A;">String(10)</font> |  | 用户ID |
| PushTime | | | <font style="color:#585A5A;">String(32)</font> |  | 推送时间，示例：`2024-06-28 11:23:51` |
| Count | | | <font style="color:#585A5A;">String(2)</font> |  | 推送的快递单号个数  <font style="color:#8A8F8D;">不超过10</font> |
| Data | <font style="color:black;">EBusinessID</font> | | <font style="color:#585A5A;">String(10)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#333333;">用户ID</font> |
| | ShipperCode | | <font style="color:#585A5A;">String(10)</font> | - [ ] <font style="color:black;"></font> | <font style="color:#8A8F8D;">快递公司编码</font> |
| | LogisticCode | | <font style="color:#585A5A;">String(30)</font> | - [ ] <font style="color:black;"></font> | 快递单号 |
| | Success | | <font style="color:#585A5A;">Bool(10)</font> | | 成功与否  <font style="color:#8A8F8D;"> (true/false)</font> |
| | Reason | | <font style="color:#585A5A;">String(50)</font> | | 失败原因 |
| | OrderCode | | <font style="color:#585A5A;">String(30)</font> | | 订单号 |
| | State | | <font style="color:#585A5A;">String(5)</font> | - [ ]  | [物流状态编码 跨境](https://www.yuque.com/kdnjishuzhichi/weubcu/mrk6deexp7v4ruxu)  |
| | StateEx | | | |
| | Location | | <font style="color:#585A5A;"></font> | | 当前城市 |
| | CallBack | | <font style="color:#585A5A;"></font> | | 自定义回传字段 |
| | Traces | AcceptTime | <font style="color:#585A5A;"></font> | | 轨迹发生时间 |
| | | AcceptStation | <font style="color:#585A5A;"></font> | | 轨迹描述 |
| | | Location | <font style="color:#585A5A;"></font> | | 历史所在城市 |
| | | Action | <font style="color:#585A5A;"></font> | | 同State |
| | | Remark | <font style="color:#585A5A;"></font> | | 备注 |


### <font style="background-color:#52C41A;"> </font>**<font style="color:rgb(38, 38, 38);"> 接口响应格式要求</font>****<font style="color:rgb(245, 34, 45);">（区分大小写）</font>**
<font style="color:rgb(38, 38, 38);">是指用户侧收到轨迹推送后，</font>**<font style="color:rgb(38, 38, 38);">对快递鸟</font>**<font style="color:rgb(38, 38, 38);">做出的响应要求</font>

| **<font style="color:rgb(255, 255, 255);">名称</font>**<font style="color:rgb(38, 38, 38);"></font> | **<font style="color:rgb(255, 255, 255);">类型</font>****<font style="color:rgb(255, 255, 255);">(长度)</font>** | **<font style="color:rgb(255, 255, 255);">是否必须</font>**<font style="color:rgb(38, 38, 38);"></font> | **<font style="color:rgb(255, 255, 255);">描述</font>**<font style="color:rgb(38, 38, 38);"></font> |
| --- | --- | --- | --- |
| <font style="color:rgb(38, 38, 38);">EBusinessID</font> | <font style="color:rgb(88, 90, 90);">String(10)</font><font style="color:rgb(38, 38, 38);"></font> | - [x] <font style="color:rgb(38, 38, 38);"></font> | <font style="color:rgb(38, 38, 38);">用户ID</font> |
| <font style="color:rgb(38, 38, 38);">UpdateTime</font> | <font style="color:rgb(88, 90, 90);">String(32)</font><font style="color:rgb(38, 38, 38);"></font> | - [x] <font style="color:rgb(38, 38, 38);"></font> | <font style="color:rgb(38, 38, 38);">更新</font><font style="color:rgb(38, 38, 38);">时间，</font>示例：`<font style="color:rgb(38, 38, 38);">2024-06-28 11:23:51</font>` |
| <font style="color:rgb(38, 38, 38);">Success</font> | <font style="color:rgb(88, 90, 90);">Bool(10)</font><font style="color:rgb(38, 38, 38);"></font> | - [x] <font style="color:rgb(38, 38, 38);"></font> | <font style="color:rgb(38, 38, 38);">成功与否</font><font style="color:rgb(38, 38, 38);">  </font><font style="color:#8A8F8D;"> (true/false)</font> |
| <font style="color:rgb(38, 38, 38);">Reason</font> | <font style="color:rgb(88, 90, 90);">String(50)</font><font style="color:rgb(38, 38, 38);"></font> | - [ ] <font style="color:rgb(38, 38, 38);"></font> | <font style="color:rgb(38, 38, 38);">失败原因</font> |


```json
{
    "EBusinessID": "1000001",
    "UpdateTime": "2024-03-11 16:26:11",
    "Success": true,
    "Reason": ""
}
```



